epistasis\.models\.linear package
=================================

epistasis\.models\.linear\.ordinary module
------------------------------------------

.. automodule:: epistasis.models.linear.ordinary
    :members:
    :undoc-members:
    :show-inheritance:

epistasis\.models\.linear\.lasso module
---------------------------------------

.. automodule:: epistasis.models.linear.lasso
    :members:
    :undoc-members:
    :show-inheritance:

epistasis\.models\.linear\.ridge module
---------------------------------------

.. automodule:: epistasis.models.linear.ridge
    :members:
    :undoc-members:
    :show-inheritance:

epistasis\.models\.linear\.elastic_net module
---------------------------------------------

.. automodule:: epistasis.models.linear.elastic_net
    :members:
    :undoc-members:
    :show-inheritance:
